require "mkmf"


def create_empty_makefile
  File.open("Makefile","w"){|file|
    file.print "all:\n"
  }
  exit 0
end

def header_not_found(name)
  warn "#{name}.h was not found, so ruby lapack will not be compiled"
  warn "If you have #{name}.h, try the following:"
  warn "  % ruby extconf.rb --with-#{name}-include=path"
  create_empty_makefile
end

def library_not_found(lname, fname=nil, flag=true)
  if fname
    warn "#{fname} was not found, so ruby lapack will not be compiled"
    warn "If you have #{lname} library, try the following:"
    warn "  % ruby extconf.rb --with-#{lname}-lib=path --with-#{lname}-name=name"
  else
    warn "lib#{lname}.{a|so} was not found, so ruby lapack will not be compiled"
    warn "If you have lib#{lname}.{a|so}, try the following:"
    warn "  % ruby extconf.rb --with-#{lname}-lib=path"
  end
  create_empty_makefile if flag
end

def find_library(lib, func, *paths, &b)
  func = "main" if !func or func.empty?
  lib = with_config(lib+'lib', lib)
  paths = paths.collect {|path| path.split(File::PATH_SEPARATOR)}.flatten
  if /\.a$/ =~ lib || /\.so$/ =~ lib
    name = lib
    libs = $libs
    $LIBPATH.each{|path|
      f = File.join(path,lib)
      if File.exist?(f)
        libs = f + " " + $libs
        break
      end
    }
  else
    name = LIBARG%lib
    libs = append_library($libs, lib)
  end
  checking_for "#{func}() in #{name}" do
    libpath = $LIBPATH
    begin
      until r = try_func(func, libs, &b) or paths.empty?
        $LIBPATH = libpath | [paths.shift]
      end
      if r
        $libs = libs
        libpath = nil
      end
    ensure
      $LIBPATH = libpath if libpath
    end
    r
  end
end




dir_config("f2c", "/usr/local")
unless find_header("f2c.h")
  header_not_found("f2c")
end
unless find_library("f2c", "s_copy")
  library_not_found("f2c")
end

dir_config("clapack", "/usr/local")
unless find_header("clapack.h")
  header_not_found("clapack")
end
#unless find_library("lapack","dsyevr_")
#  library_not_found("lapack",nil,false)

  warn "CLAPACK will be tried to find"
  name = with_config("cblas-name","blas_LINUX.a")
  unless find_library(name,"f2c_dcopy")
    library_not_found("cblas",name)
  end
  name = with_config("clapack-name","lapack_LINUX.a")
  unless find_library(name,"dsyevr_")
    library_not_found("lapack",name)
  end
#end

sitearchdir = Config::CONFIG["sitearchdir"]
dir_config("narray", sitearchdir, sitearchdir)
unless find_header("narray.h") && have_header("narray_config.h")
  header_not_found("narray")
end
unless find_library("narray.so","na_make_object")
  library_not_found("narray","narray.so")
end

create_makefile("numru/lapack")
